#
# spec file for package cppreference-doc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cppreference-doc
Version:        20241110
Release:        1.3
Summary:        Cppreference documentation for offline reading
License:        CC-BY-SA-3.0
Group:          Documentation/HTML
URL:            http://en.cppreference.com/w/
Source0:        https://github.com/PeterFeicht/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM cppreference-doc-premailer-3.9-compat.patch badshah400@gmail.com -- Fix building against premailer >= 3.9
Patch0:         cppreference-doc-premailer-3.9-compat.patch
BuildRequires:  devhelp
BuildRequires:  fdupes
BuildRequires:  libqt5-qttools
%if 0%{?suse_version} < 1550
BuildRequires:  python3-cssutils
%else
# At least version 2.0.0 of cssutils is required for building on oS 1550
BuildRequires:  python3-cssutils >= 2.0.0
%endif
BuildRequires:  python3-lxml
BuildRequires:  python3-premailer
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Cppreference is a complete online reference for the C and C++ languages and standard libraries, i.e. a more convenient version of the C and C++ standards. This package provides an offline mirror of the reference.

%package devhelp
Summary:        Cppreference documentation for offline reading - devhelp version
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description devhelp
Cppreference is a complete online reference for the C and C++ languages and standard libraries, i.e. a more convenient version of the C and C++ standards. This package provides an offline mirror of the reference in the devhelp format.

This package provides the documentation in the devhelp format.

%package qhelp
Summary:        Cppreference documentation for offline reading - qhelp version
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description qhelp
Cppreference is a complete online reference for the C and C++ languages and standard libraries, i.e. a more convenient version of the C and C++ standards. This package provides an offline mirror of the reference in the devhelp format.

This package provides the documentation in the qhelp format.

%prep
%autosetup -p1

%build
make %{?_smp_mflags} qhelpgenerator=qhelpgenerator-qt5

%install
%make_install

rm %{buildroot}%{_datadir}/devhelp/books/cppreference-doxygen*.xml

%fdupes %{buildroot}%{_datadir}/cppreference/

%files
%doc README.md
%dir %{_datadir}/cppreference
%dir %{_datadir}/cppreference/doc
%{_datadir}/cppreference/doc/html/

%files devhelp
%{_datadir}/devhelp/books/cppreference-doc-en-c/
%{_datadir}/devhelp/books/cppreference-doc-en-cpp/

%files qhelp
%dir %{_datadir}/cppreference/doc/qch
%{_datadir}/cppreference/doc/qch/

%changelog
* Sat Nov 16 2024 Markus Ebner <info@ebner-markus.de>
- Update to version 20241110
  * Update content from the website.
  * Various build improvements.
* Tue Jun 18 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20240610:
  * Update content from the website, long overdue.
* Sat Aug 26 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20230810:
  * No upstream release notes.
* Mon Oct 24 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add cppreference-doc-premailer-3.9-compat.patch: Make
  pre-processing compatible with premailer >= 3.9.
* Thu Sep 15 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add BuildRequires: python3-cssutils for all openSUSE versions,
  but specifically require version 2.0.0 and above for oS 1550 to
  avoid build failures.
* Wed Aug 10 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20220730:
  * No upstream release notes.
* Sat Feb  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20220201:
  * No upstream release notes.
* Wed Dec 15 2021 Markus Ebner <info@ebner-markus.de>
- Update to version 20211127
  (Switched to PeterFeicht's repository, which has new releases)
- Removed preprocess_qch.py - now bundled in source
* Tue Aug 27 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 20190607:
  + List of changes unavailable from upstream.
- Drop Fix-qch-build.patch: incorporate upstream.
- Add a build script missed by upstream tarball
  (preprocess_qch.py).
- New build dependency: python3-premailer.
* Tue Apr  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add Fix-qch-build.patch to fix the qch generation.
* Wed Mar 28 2018 badshah400@gmail.com
- Initial version
